@@ -1,8 +1,5 @@
 /*
-x86_64/amd64 threaded, PL_sig_pending in rcx?
-my_perl already on stack, moved to rbx, Iop at 8(%rbx)
-per amd64 calling-convention the single pTHX arg (my_perl) 
-is in %rdi, not on the stack.
+x86_64/amd64 threaded, PL_op in rax, PL_sig_pending in rbx
 
   4008f4:	53                   	push   %rbx
   4008f5:	31 db                	xor    %ebx,%ebx
@@ -32,11 +29,13 @@ is in %rdi, not on the stack.
 */
 
 T_CHARARR amd64thr_prolog[] = {
-    enter_8,
-    push_rbx,
-    mov_rax_rbx       /* my_perl => rbx */
+    push_rbp,
+    mov_rsp_rbp,
+    sub_x_rsp(8),
+    push_r12
 #ifdef HAVE_DISPATCH
-    ,push_rcx		/* &sigpending (myperl[xx]) => rcx */
+    ,push_rbx,
+    0x31,0xdb             /* xor    %ebx,%ebx */
 #endif
 };
 unsigned char *push_prolog(unsigned char *code) {
@@ -44,81 +43,52 @@ unsigned char *push_prolog(unsigned char *code) {
     return code;
 }
 T_CHARARR amd64thr_epilog[] = {
-    mov_0_rax, /* nullify PL_op */
 #ifdef HAVE_DISPATCH
-    pop_rcx,
-#endif
     pop_rbx,
+#endif
+    pop_r12,
+    add_x_esp(8),
     leave,
     ret
 };
 
-#define mov_rax_8rbx 	0x48,0x89,0x43,0x08
-
 T_CHARARR amd64thr_call[]  = {
-    mov_rbx_arg1,	/* mov    %rbx,%rdi ; my_perl => arg1 */
-    call};      	/* callq near offset $PL_op->op_ppaddr */
+    0x48,0x89,0xdf,	/* mov    %rbx,%rdi */
+    0x48,0x89,0x43,0x08,  /* mov    %rax,0x8(%rbx) */
+    0xe8};      		/* callq near offset $PL_op->op_ppaddr */
 T_CHARARR amd64thr_jmp[]   = {0xff,0x25}; /* jmp *$PL_op->op_ppaddr */
-T_CHARARR amd64thr_save_plop[]  = { /* save new PL_op into my_perl */
-    mov_rax_8rbx	/* mov    %rax,0x8(%rbx) */ 
-};
+T_CHARARR amd64thr_save_plop[]  = {
+    0x48,0x89,0x05  /* mov %rax,0x5d14ec(%rip) #save new PL_op */
+};      
 T_CHARARR amd64thr_nop2[]       = {0x90,0x90};      /* jmp pad */
 T_CHARARR amd64thr_dispatch_getsig[] = {
-    mov_mem_rcx};
+    0x8b,0x0d};
+/*
+  74 08                	je     40092c <main+0x38>
+  48 89 df             	mov    %rbx,%rdi
+  e8 8c fe ff ff       	callq  4007b8 <Perl_despatch_signals@plt>
+  31 db                	xor    %ebx,%ebx
+*/
 T_CHARARR amd64thr_dispatch[] = {
-    test_rcx_rcx,
-    je(8)};
+    0x85,0xc9,0x74,0x06,
+    0xFF,0x25};
+T_CHARARR amd64thr_dispatch_post[] = {0x31,0xdb};
 
+#define mov_rbx_rdi 	0x48,0x89,0xdf
+#define mov_rax_8rbx 	0x48,0x89,0x43,0x08
 #define mov_rrax_r12	0x4c,0x8b,0x20
 
 T_CHARARR maybranch_plop[] = {
-    mov_mem_rebp8, fourbyte
+    mov_rbx_rdi,
+    mov_rax_8rbx,
+    mov_rrax_r12
 };
 unsigned char *
-push_maybranch_plop(unsigned char *code, OP* next) {
-    T_CHARARR maybranch_plop1[] = {
-	mov_mem_rebp8};
-    PUSHc(maybranch_plop1);
-    PUSHabs(next);
-    return code;
-}
-T_CHARARR maybranch_check[] = {
-    cmp_eax_rebp8,
-    je(0)
-};
-T_CHARARR maybranch_checkw[] = {
-    cmp_eax_rebp8,
-    jew(0)
-};
-unsigned char *
-push_maybranch_check(unsigned char *code, int next) {
-    CODE maybranch_check[] = {
-	cmp_eax_rebp8,
-	je_0};
-    if (abs(next) > 128) {
-        CODE maybranch_checkw[] = {
-	    cmp_eax_rebp8,
-            jew_0};
-        PUSHc(maybranch_checkw);
-        PUSHrel(next);
-    } else {
-        PUSHc(maybranch_check);
-        PUSHbyte(next);
-    }
+push_maybranch_plop(unsigned char *code) {
+    PUSHc(maybranch_plop);
     return code;
 }
 
-T_CHARARR gotorel[] = {
-    0xe9, fourbyte
-};
-unsigned char *
-push_gotorel(unsigned char *code, U32 label) {
-    T_CHARARR gotorel[] = {
-	0xe9};
-    PUSHc(gotorel);
-    PUSHabs(&label);
-    return code;
-}
 
 # define PROLOG 	amd64thr_prolog
 # define CALL	 	amd64thr_call
@@ -126,9 +96,8 @@ push_gotorel(unsigned char *code, U32 label) {
 # define SAVE_PLOP	amd64thr_save_plop
 # define DISPATCH_GETSIG amd64thr_dispatch_getsig
 # define DISPATCH       amd64thr_dispatch
+# define DISPATCH_POST  amd64thr_dispatch_post
 # define EPILOG         amd64thr_epilog
-# define MAYBRANCH_PLOP maybranch_plop
-# define GOTOREL        gotorel
 
 /*
  * Local variables:
